@@ -80,6 +80,7 @@ extern char *strstr();	/* needed on sysV68 R3V7.1. */
 int batchcount;		/* count of messages sent in current batch */
 flag peek_capable;	/* can we peek for better error recovery? */
 int pass;		/* how many times have we re-polled? */
+int stage;		/* where are we? */
 int phase;		/* where are we, for error-logging purposes? */
 
 static const struct method *protocol;
@@ -241,7 +242,7 @@ static void find_server_names(const char *hdr,
  * are not uncommon.  So now we just check that the following token is
  * not itself an email address.
  */
-#define VALID_ADDRESS(a)	!strchr(rbuf, '@')
+#define VALID_ADDRESS(a)	!strchr(a, '@')
 
 static char *parse_received(struct query *ctl, char *bufp)
 /* try to extract real address from the Received line */
@@ -542,16 +543,20 @@ static int readheaders(int sock,
 
 	/*
 	 * When mail delivered to a multidrop mailbox on the server is
-	 * addressed to multiple people, there will be one copy left
-	 * in the box for each recipient.  Thus, if the mail is addressed
-	 * to N people, each recipient would get N copies.
+	 * addressed to multiple people on the client machine, there
+	 * will be one copy left in the box for each recipient.  Thus,
+	 * if the mail is addressed to N people, each recipient will
+	 * get N copies.
 	 *
 	 * Foil this by suppressing all but one copy of a message with
 	 * a given Message-ID.  Note: This implementation only catches
 	 * runs of successive identical messages, but that should be
-	 * good enough.
+	 * good enough. 
+	 * 
+	 * The accept_count test ensures that multiple pieces of identical 
+	 * email, each with a *single* addressee, won't be suppressed.
 	 */
-	if (MULTIDROP(ctl) && !strncasecmp(line, "Message-ID:", 11))
+	if (MULTIDROP(ctl) && accept_count > 1 && !strncasecmp(line, "Message-ID:", 11))
 	{
 	    if (ctl->lastid && !strcasecmp(ctl->lastid, line))
 		return(PS_REFUSED);
@@ -577,7 +582,11 @@ static int readheaders(int sock,
 	 * forward it to the user so he or she will have some clue
 	 * that things have gone awry.
 	 */
+#if INET6_ENABLE
+	if (strncmp(protocol->service, "pop2", 4))
+#else /* INET6_ENABLE */
 	if (protocol->port != 109)
+#endif /* INET6_ENABLE */
 #endif /* POP2_ENABLE */
 	    if (num == 1 && !strncasecmp(line, "X-IMAP:", 7)) {
 		free(line);
@@ -889,7 +898,7 @@ static int readheaders(int sock,
 	     * We haven't extracted the envelope address.
 	     * So check all the "Resent-To" header addresses if 
 	     * they exist.  If and only if they don't, consider
-	     * the "To" adresses.
+	     * the "To" addresses.
 	     */
 	    register struct addrblk *nextptr;
 	    if (resent_to_addrchain) {
@@ -1205,7 +1214,10 @@ static int readbody(int sock, struct query *ctl, flag forward, int len)
 		return(PS_IOERR);
 	    }
 	    else if (outlevel >= O_VERBOSE)
-		fputc('*', stderr);
+	    {
+		fputc('*', stdout);
+		fflush(stdout);
+	    }
 	}
     }
 
@@ -1505,18 +1517,16 @@ const int maxfetch;		/* maximum number of messages to fetch */
 		stuff_warning(ctl,
 			      _("Subject: fetchmail sees repeated timeouts\r\n"));
 		stuff_warning(ctl,
-			      _("Fetchmail saw more than %d timouts while attempting to get mail from %s@%s.\n"), 
+			      _("Fetchmail saw more than %d timeouts while attempting to get mail from %s@%s.\r\n"), 
 			      MAX_TIMEOUTS,
 			      ctl->remotename,
 			      ctl->server.truename);
 		stuff_warning(ctl, 
-			      _("This could mean that your mailserver is stuck, or that your SMTP listener"));
-		stuff_warning(ctl, 
-			      _("is wedged, or that your mailbox file on the server has been corrupted by"));
-		stuff_warning(ctl, 
-			      _("a server error.  You can run `fetchmail -v -v' to diagnose the problem."));
-		stuff_warning(ctl,
-			      _("Fetchmail won't poll this mailbox again until you restart it."));
+    _("This could mean that your mailserver is stuck, or that your SMTP\r\n" \
+    "server is wedged, or that your mailbox file on the server has been\r\n" \
+    "corrupted by a server error.  You can run `fetchmail -v -v' to\r\n" \
+    "diagnose the problem.\r\n\r\n" \
+    "Fetchmail won't poll this mailbox again until you restart it.\r\n"));
 		close_warning_by_mail(ctl, (struct msgblk *)NULL);
 		ctl->wedged = TRUE;
 	    }
@@ -1535,11 +1545,11 @@ const int maxfetch;		/* maximum number of messages to fetch */
     {
 	char buf[POPBUFSIZE+1], *realhost;
 	int len, num, count, new, bytes, deletions = 0, *msgsizes = NULL;
-#if INET6
+#if INET6_ENABLE
 	int fetches, dispatches, oldphase;
-#else /* INET6 */
+#else /* INET6_ENABLE */
 	int port, fetches, dispatches, oldphase;
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
 	struct idlist *idp;
 
 	/* execute pre-initialization command, if any */
@@ -1555,23 +1565,27 @@ const int maxfetch;		/* maximum number of messages to fetch */
 	oldphase = phase;
 	phase = OPEN_WAIT;
 	set_timeout(mytimeout);
-#if !INET6
+#if !INET6_ENABLE
+#ifdef SSL_ENABLE
+	port = ctl->server.port ? ctl->server.port : ( ctl->use_ssl ? protocol->sslport : protocol->port );
+#else
 	port = ctl->server.port ? ctl->server.port : protocol->port;
-#endif /* !INET6 */
+#endif
+#endif /* !INET6_ENABLE */
 	realhost = ctl->server.via ? ctl->server.via : ctl->server.pollname;
 
 	/* allow time for the port to be set up if we have a plugin */
 	if (ctl->server.plugin)
 	    (void)sleep(1);
-#if INET6
+#if INET6_ENABLE
 	if ((mailserver_socket = SockOpen(realhost, 
 			     ctl->server.service ? ctl->server.service : protocol->service,
 			     ctl->server.netsec, ctl->server.plugin)) == -1)
-#else /* INET6 */
+#else /* INET6_ENABLE */
 	if ((mailserver_socket = SockOpen(realhost, port, NULL, ctl->server.plugin)) == -1)
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
 	{
-#if !INET6
+#if !INET6_ENABLE
 	    int err_no = errno;
 #ifdef HAVE_RES_SEARCH
 	    if (err_no != 0 && h_errno != 0)
@@ -1606,7 +1620,7 @@ const int maxfetch;		/* maximum number of messages to fetch */
 		report_complete(stderr, ": %s\n", strerror(err_no));
 
 	ehostunreach:
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
 	    ok = PS_SOCKET;
 	    set_timeout(0);
 	    phase = oldphase;
@@ -1615,6 +1629,17 @@ const int maxfetch;		/* maximum number of messages to fetch */
 	set_timeout(0);
 	phase = oldphase;
 
+#ifdef SSL_ENABLE
+	/* perform initial SSL handshake on open connection */
+	/* Note:  We pass the realhost name over for certificate
+		verification.  We may want to make this configurable */
+	if (ctl->use_ssl && SSLOpen(mailserver_socket,ctl->sslkey,ctl->sslcert,realhost) == -1) 
+	{
+	    report(stderr, "SSL connection failed.");
+	    goto closeUp;
+	}
+#endif
+
 #ifdef KERBEROS_V4
 	if (ctl->server.preauthenticate == A_KERBEROS_V4)
 	{
@@ -1643,6 +1668,7 @@ const int maxfetch;		/* maximum number of messages to fetch */
 	    goto cleanUp;
 
 	/* try to get authorized to fetch mail */
+	stage = STAGE_GETAUTH;
 	if (protocol->getauth)
 	{
 	    if (protocol->password_canonify)
@@ -1657,10 +1683,8 @@ const int maxfetch;		/* maximum number of messages to fetch */
 		    report(stderr, _("Lock-busy error on %s@%s\n"),
 			  ctl->remotename,
 			  ctl->server.truename);
-		else
+		else if (ok == PS_AUTHFAIL)
 		{
-		    if (ok == PS_ERROR)
-			ok = PS_AUTHFAIL;
 		    report(stderr, _("Authorization failure on %s@%s\n"), 
 			  ctl->remotename,
 			  ctl->server.truename);
@@ -1676,19 +1700,25 @@ const int maxfetch;		/* maximum number of messages to fetch */
 			&& !open_warning_by_mail(ctl, (struct msgblk *)NULL))
 		    {
 			stuff_warning(ctl,
-			       _("Subject: fetchmail authentication failed\r\n"));
+			    _("Subject: fetchmail authentication failed\r\n"));
 			stuff_warning(ctl,
-				_("Fetchmail could not get mail from %s@%s."), 
-				ctl->remotename,
-				ctl->server.truename);
+			    _("Fetchmail could not get mail from %s@%s.\r\n"), 
+			    ctl->remotename,
+			    ctl->server.truename);
 			stuff_warning(ctl, 
-			       _("The attempt to get authorization failed."));
-			stuff_warning(ctl, 
-			       _("This probably means your password is invalid."));
+    _("The attempt to get authorization failed.\r\n" \
+    "This probably means your password is invalid, but POP3 servers have\r\n" \
+    "other failure modes that fetchmail cannot distinguish from this\r\n" \
+    "because they don't send useful error messages on login failure.\r\n"));
 			close_warning_by_mail(ctl, (struct msgblk *)NULL);
 			ctl->wedged = TRUE;
 		    }
 		}
+		else
+		    report(stderr, _("Unknown login or authentication error on %s@%s\n"),
+			  ctl->remotename,
+			  ctl->server.truename);
+		    
 		goto cleanUp;
 	    }
 	}
@@ -1712,6 +1742,7 @@ const int maxfetch;		/* maximum number of messages to fetch */
 		}
 
 		/* compute # of messages and number of new messages waiting */
+		stage = STAGE_GETRANGE;
 		ok = (protocol->getrange)(mailserver_socket, ctl, idp->id, &count, &new, &bytes);
 		if (ok != 0)
 		    goto cleanUp;
@@ -1810,6 +1841,7 @@ const int maxfetch;		/* maximum number of messages to fetch */
 			for (i = 0; i < count; i++)
 			    msgsizes[i] = -1;
 
+			stage = STAGE_GETSIZES;
 			ok = (proto->getsizes)(mailserver_socket, count, msgsizes);
 			if (ok != 0)
 			    goto cleanUp;
@@ -1823,6 +1855,7 @@ const int maxfetch;		/* maximum number of messages to fetch */
 		    }
 
 		    /* read, forward, and delete messages */
+		    stage = STAGE_FETCH;
 		    for (num = 1; num <= count; num++)
 		    {
 			flag toolarge = NUM_NONZERO(ctl->limit)
@@ -2163,7 +2196,10 @@ const int maxfetch;		/* maximum number of messages to fetch */
     cleanUp:
 	/* we only get here on error */
 	if (ok != 0 && ok != PS_SOCKET)
+	{
+	    stage = STAGE_LOGOUT;
 	    (protocol->logout_cmd)(mailserver_socket, ctl);
+	}
 	SockClose(mailserver_socket);
     }
 
