@@ -34,6 +34,7 @@
 #ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
 #endif /* HAVE_SYS_WAIT_H */
+#include <sys/utsname.h>
 
 #ifdef HAVE_GETHOSTBYNAME
 #include <netdb.h>
@@ -80,25 +81,24 @@ int requestlen = 0;
 #endif /* NET_SECURITY */
 
 static char *lockfile;		/* name of lockfile */
+static int lock_acquired;	/* have we acquired a lock */
 static int querystatus;		/* status of query */
 static int successes;		/* count number of successful polls */
 static struct runctl cmd_run;	/* global options set from command line */
+static time_t parsetime;	/* time of last parse */
 
-static void termhook(int);		/* forward declaration of exit hook */
-
-#if 0
-#define SLEEP_WITH_ALARM
-#endif
+static void terminate_run(int);
+static void terminate_poll(int);
 
 #ifdef SLEEP_WITH_ALARM
 /*
  * The function of this variable is to remove the window during which a
  * SIGALRM can hose the code (ALARM is triggered *before* pause() is called).
  * This is a bit of a kluge; the real right thing would use sigprocmask(),
- * sigsuspend().
- * This work around lets the interval timer trigger the first alarm after the
- * required interval and will then generate alarms all 5 seconds, until it
- * is certain, that the critical section (ie., the window) is left.
+ * sigsuspend().  This workaround lets the interval timer trigger the first
+ * alarm after the required interval and will then generate alarms all 5
+ * seconds, until it is certain, that the critical section (ie., the window)
+ * is left.
  */
 #if defined(STDC_HEADERS)
 static sig_atomic_t	alarm_latch = FALSE;
@@ -125,7 +125,8 @@ static void unlockit(void)
 #endif
 /* must-do actions for exit (but we can't count on being able to do malloc) */
 {
-    unlink(lockfile);
+    if (lockfile && lock_acquired)
+	unlink(lockfile);
 }
 
 #ifdef __EMX__
@@ -133,7 +134,7 @@ static void unlockit(void)
 int itimerflag;
 void itimerthread(void* dummy) {
   if (outlevel >= O_VERBOSE)
-    fprintf(stderr, _("fetchmail: thread sleeping for %d sec.\n"), poll_interval);
+    report(stderr, _("fetchmail: thread sleeping for %d sec.\n"), poll_interval);
   while(1) {
     _sleep2(poll_interval*1000);
     kill((getpid()), SIGALRM);
@@ -182,14 +183,44 @@ int main(int argc, char **argv)
     textdomain(PACKAGE);
 #endif
 
+    /*
+     * Note: because we can't initialize reporting before we  know whether
+     * syslog is supposed to be on, this message will go to stdout and
+     * be lost when running in background.
+     */
+    if (outlevel >= O_VERBOSE)
+    {
+	int i;
+
+	report(stdout, "fetchmail: invoked with");
+	for (i = 0; i < argc; i++)
+	    report(stdout, " %s", argv[i]);
+	report(stdout, "\n");
+    }
+
 #define IDFILE_NAME	".fetchids"
-    run.idfile = (char *) xmalloc(strlen(home)+strlen(IDFILE_NAME)+2);
+    run.idfile = (char *) xmalloc(strlen(home)+sizeof(IDFILE_NAME)+1);
     strcpy(run.idfile, home);
     strcat(run.idfile, "/");
     strcat(run.idfile, IDFILE_NAME);
   
     outlevel = O_NORMAL;
 
+    /*
+     * We used to arrange for the lockfile to be removed on exit close
+     * to where the lock was asserted.  Now we need to do it here, because
+     * we might have re-executed in background with an existing lockfile
+     * as the result of a changed rcfile (see the code near the execvp(3)
+     * call near the beginning of the polling loop for details).  We want
+     * to be sure the lockfile gets nuked on any error exit, basically.
+     */
+#ifdef HAVE_ATEXIT
+    atexit(unlockit);
+#endif
+#ifdef HAVE_ON_EXIT
+    on_exit(unlockit, (char *)NULL);
+#endif
+
     if ((parsestatus = parsecmdline(argc,argv, &cmd_run, &cmd_opts)) < 0)
 	exit(PS_SYNTAX);
 
@@ -220,24 +251,26 @@ int main(int argc, char **argv)
 #ifndef ETRN_ENABLE
 	printf("-ETRN");
 #endif /* ETRN_ENABLE */
-#if OPIE
+#ifdef SSL_ENABLE
+	printf("+SSL");
+#endif
+#if OPIE_ENABLE
 	printf("+OPIE");
-#endif /* OPIE */
-#if INET6
+#endif /* OPIE_ENABLE */
+#if INET6_ENABLE
 	printf("+INET6");
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
 #if NET_SECURITY
 	printf("+NETSEC");
 #endif /* NET_SECURITY */
 #ifdef HAVE_SOCKS
-  #if HAVE_SOCKS
 	printf("+SOCKS");
-  #endif
 #endif /* HAVE_SOCKS */
 #if ENABLE_NLS
 	printf("+NLS");
 #endif /* ENABLE_NLS */
 	putchar('\n');
+	fflush(stdout);
 
 	/* this is an attempt to help remote debugging */
 	system("uname -a");
@@ -247,14 +280,25 @@ int main(int argc, char **argv)
     if (!(quitmode && argc == 2))
 	implicitmode = load_params(argc, argv, optind);
 
+#if defined(HAVE_SYSLOG)
+    /* logging should be set up early in case we were restarted from exec */
+    if (run.use_syslog)
+    {
+	openlog(program_name, LOG_PID, LOG_MAIL);
+	report_init(-1);
+    }
+    else
+#endif
+	report_init((run.poll_interval == 0 || nodetach) && !run.logfile);
+
     /* set up to do lock protocol */
 #define	FETCHMAIL_PIDFILE	"fetchmail.pid"
     if (!getuid()) {
 	xalloca(tmpbuf, char *,
-		strlen(PID_DIR) + strlen(FETCHMAIL_PIDFILE) + 2);
+		sizeof(PID_DIR) + sizeof(FETCHMAIL_PIDFILE));
 	sprintf(tmpbuf, "%s/%s", PID_DIR, FETCHMAIL_PIDFILE);
     } else {
-	xalloca(tmpbuf, char *, strlen(home) + strlen(FETCHMAIL_PIDFILE) + 3);
+	xalloca(tmpbuf, char *, strlen(home) + sizeof(FETCHMAIL_PIDFILE) + 2);
 	strcpy(tmpbuf, home);
 	strcat(tmpbuf, "/.");
 	strcat(tmpbuf, FETCHMAIL_PIDFILE);
@@ -278,7 +322,7 @@ int main(int argc, char **argv)
 
 #define	NETRC_FILE	".netrc"
     /* parse the ~/.netrc file (if present) for future password lookups. */
-    xalloca(netrc_file, char *, strlen (home) + strlen(NETRC_FILE) + 2);
+    xalloca(netrc_file, char *, strlen (home) + sizeof(NETRC_FILE) + 1);
     strcpy (netrc_file, home);
     strcat (netrc_file, "/");
     strcat (netrc_file, NETRC_FILE);
@@ -325,17 +369,19 @@ int main(int argc, char **argv)
     /* perhaps we just want to check options? */
     if (versioninfo)
     {
-	printf(_("Taking options from command line"));
-	if (access(rcfile, 0))
-	    printf("\n");
-	else
-	    printf(_(" and %s\n"), rcfile);
+	int havercfile = access(rcfile, 0);
+
+	printf(_("Taking options from command line%s%s\n"),
+				havercfile ? "" :  _(" and "),
+				havercfile ? "" : rcfile);
+
 	if (outlevel >= O_VERBOSE)
 	    printf(_("Lockfile at %s\n"), tmpbuf);
 
 	if (querylist == NULL)
-	    (void) fprintf(stderr,
-		_("No mailservers set up -- perhaps %s is missing?\n"), rcfile);
+	    fprintf(stderr,
+		    _("No mailservers set up -- perhaps %s is missing?\n"),
+		    rcfile);
 	else
 	    dump_params(&run, querylist, implicitmode);
 	exit(0);
@@ -352,7 +398,7 @@ int main(int argc, char **argv)
     pid = -1;
     if ((lockfile = (char *) malloc(strlen(tmpbuf) + 1)) == NULL)
     {
-	fprintf(stderr,_("fetchmail: cannot allocate memory for lock name.\n"));
+	report(stderr,_("fetchmail: cannot allocate memory for lock name.\n"));
 	exit(PS_EXCLUDE);
     }
     else
@@ -367,7 +413,7 @@ int main(int argc, char **argv)
 	    bkgd = FALSE;
 	    unlink(lockfile);
 	}
-	fclose(lockfp);
+	fclose(lockfp);	/* not checking should be safe, file mode was "r" */
     }
 
     /* if no mail servers listed and nothing in background, we're done */
@@ -428,9 +474,15 @@ int main(int argc, char **argv)
 	}
 	else if (argc > 1)
 	{
-	    fprintf(stderr,
-		    _("fetchmail: can't accept options while a background fetchmail is running.\n"));
-	    return(PS_EXCLUDE);
+	    /* this test enables re-execing on a changed rcfile */
+	    if (getpid() == pid)
+		lock_acquired = TRUE;
+	    else
+	    {
+		fprintf(stderr,
+			_("fetchmail: can't accept options while a background fetchmail is running.\n"));
+		return(PS_EXCLUDE);
+	    }
 	}
 	else if (kill(pid, SIGUSR1) == 0)
 	{
@@ -475,34 +527,22 @@ int main(int argc, char **argv)
 	}
     }
 
-/* Time to initiate the SOCKS library (this is not mandatory: it just
- registers the correct application name for logging purpose. If you
- have some problem, comment these lines). */
+    /*
+     * Time to initiate the SOCKS library (this is not mandatory: it just
+     * registers the correct application name for logging purpose. If you
+     * have some problem, comment out these lines).
+     */
 #ifdef HAVE_SOCKS
-  #if HAVE_SOCKS
-/* Mmmh... I don't like hardcoded application names,
- but "fetchmail" is everywhere... */
     SOCKSinit("fetchmail");
-  #endif
 #endif /* HAVE_SOCKS */
 
     /*
      * Maybe time to go to demon mode...
      */
-#if defined(HAVE_SYSLOG)
-    if (run.use_syslog)
-    {
-    	openlog(program_name, LOG_PID, LOG_MAIL);
-	report_init(-1);
-    }
-    else
-#endif
-	report_init((run.poll_interval == 0 || nodetach) && !run.logfile);
-
     if (run.poll_interval)
     {
 	if (!nodetach)
-	    daemonize(run.logfile, termhook);
+	    daemonize(run.logfile, terminate_run);
 	report(stdout, _("starting fetchmail %s daemon \n"), VERSION);
 
 	/*
@@ -513,6 +553,12 @@ int main(int argc, char **argv)
 	if (run.poll_interval && !getuid())
 	    signal(SIGHUP, SIG_IGN);
     }
+    else if (run.logfile && access(run.logfile, F_OK) == 0)
+    {
+	freopen(run.logfile, "a", stdout);
+	freopen(run.logfile, "a", stderr);
+    }
+
 
 #ifdef linux
     interface_init();
@@ -520,12 +566,12 @@ int main(int argc, char **argv)
 
     /* beyond here we don't want more than one fetchmail running per user */
     umask(0077);
-    signal(SIGABRT, termhook);
-    signal(SIGINT, termhook);
-    signal(SIGTERM, termhook);
-    signal(SIGALRM, termhook);
-    signal(SIGPIPE, termhook);
-    signal(SIGQUIT, termhook);
+    signal(SIGABRT, terminate_run);
+    signal(SIGINT, terminate_run);
+    signal(SIGTERM, terminate_run);
+    signal(SIGALRM, terminate_run);
+    signal(SIGPIPE, terminate_run);
+    signal(SIGQUIT, terminate_run);
 
     /* here's the exclusion lock */
     if ((st = open(lockfile, O_WRONLY | O_CREAT | O_EXCL, 0666)) != -1) {
@@ -536,14 +582,8 @@ int main(int argc, char **argv)
 	    sprintf(tmpbuf," %d", run.poll_interval);
 	    write(st, tmpbuf, strlen(tmpbuf));
 	}
-	close(st);
-
-#ifdef HAVE_ATEXIT
-	atexit(unlockit);
-#endif
-#ifdef HAVE_ON_EXIT
-	on_exit(unlockit, (char *)NULL);
-#endif
+	close(st);	/* should be safe, previous write was atomic */
+	lock_acquired = TRUE;
     }
 
     /*
@@ -551,6 +591,24 @@ int main(int argc, char **argv)
      * reflect the status of that transaction.
      */
     do {
+	/* 
+	 * Check to see if the rcfile has been touched.  If so,
+	 * re-exec so the file will be reread.  Doing it this way
+	 * avoids all the complications of trying to deallocate the
+	 * in-core control structures -- and the potential memory
+	 * leaks...
+	 */
+	struct stat	rcstat;
+
+	if (stat(rcfile, &rcstat) == -1)
+	    report(stderr, _("couldn't time-check %s\n"), rcfile);
+	else if (rcstat.st_mtime > parsetime)
+	{
+	    report(stdout, _("restarting fetchmail (%s changed)\n"), rcfile);
+	    execvp("fetchmail", argv);
+	    report(stderr, _("attempt to re-exec fetchmail failed\n"));
+	}
+
 #if defined(HAVE_RES_SEARCH) && defined(USE_TCPIP_FOR_DNS)
 	/*
 	 * This was an efficiency hack that backfired.  The theory
@@ -591,36 +649,26 @@ int main(int argc, char **argv)
 		    }
 		}
 
-#if (defined(linux) && !INET6) || defined(__FreeBSD__)
+#if (defined(linux) && !INET6_ENABLE) || defined(__FreeBSD__)
 		/* interface_approve() does its own error logging */
 		if (!interface_approve(&ctl->server))
 		    continue;
-#endif /* (defined(linux) && !INET6) || defined(__FreeBSD__) */
+#endif /* (defined(linux) && !INET6_ENABLE) || defined(__FreeBSD__) */
 
 		querystatus = query_host(ctl);
 
-		if (querystatus == PS_SUCCESS)
-		{
-		    successes++;
 #ifdef POP3_ENABLE
-		    if (!check_only)
-			update_str_lists(ctl);
-
-		   /* Save UID list to prevent re-fetch in case fetchmail 
-		      recover from crash */
-		    if (!check_only)
-		    {
-			write_saved_lists(querylist, run.idfile);
-			if (outlevel >= O_DEBUG)
-			    report(stdout, _("saved UID List\n"));
-		    }
+		if (!check_only)
+		    uid_end_query(ctl);
 #endif  /* POP3_ENABLE */
-		}
+
+		if (querystatus == PS_SUCCESS)
+		    successes++;
 		else if (!check_only && 
 			 ((querystatus!=PS_NOMAIL) || (outlevel==O_DEBUG)))
 		    report(stdout, _("Query status=%d\n"), querystatus);
 
-#if (defined(linux) && !INET6) || defined (__FreeBSD__)
+#if (defined(linux) && !INET6_ENABLE) || defined (__FreeBSD__)
 		if (ctl->server.monitor)
 		{
 		    /*
@@ -631,7 +679,7 @@ int main(int argc, char **argv)
 		    sleep(3);
 		    interface_note_activity(&ctl->server);
 		}
-#endif /* (defined(linux) && !INET6) || defined(__FreeBSD__) */
+#endif /* (defined(linux) && !INET6_ENABLE) || defined(__FreeBSD__) */
 	    }
 	}
 
@@ -639,21 +687,8 @@ int main(int argc, char **argv)
 	endhostent();		/* release TCP/IP connection to nameserver */
 #endif /* HAVE_RES_SEARCH */
 
-	/*
-	 * Close all SMTP delivery sockets.  For optimum performance
-	 * we'd like to hold them open til end of run, but (1) this
-	 * loses if our poll interval is longer than the MTA's inactivity
-	 * timeout, and (2) some MTAs (like smail) don't deliver after
-	 * each message, but rather queue up mail and wait to actually
-	 * deliver it until the input socket is closed. 
-	 */
-	for (ctl = querylist; ctl; ctl = ctl->next)
-	    if (ctl->smtp_socket != -1)
-	    {
-		SMTP_quit(ctl->smtp_socket);
-		close(ctl->smtp_socket);
-		ctl->smtp_socket = -1;
-	    }
+	/* close connections cleanly */
+	terminate_poll(0);
 
 	/*
 	 * OK, we've polled.  Now sleep.
@@ -676,6 +711,7 @@ int main(int argc, char **argv)
 	    if (!unwedged)
 	    {
 		report(stderr, _("All connections are wedged.  Exiting.\n"));
+		/* FIXME: someday, send notification mail */
 		exit(PS_AUTHFAIL);
 	    }
 
@@ -806,7 +842,7 @@ int main(int argc, char **argv)
 	report(stdout, _("normal termination, status %d\n"),
 		successes ? PS_SUCCESS : querystatus);
 
-    termhook(0);
+    terminate_run(0);
     exit(successes ? PS_SUCCESS : querystatus);
 }
 
@@ -831,12 +867,12 @@ static void optmerge(struct query *h2, struct query *h1, int force)
 #define FLAG_MERGE(fld) if (force ? !!h1->fld : !h2->fld) h2->fld = h1->fld
     FLAG_MERGE(server.via);
     FLAG_MERGE(server.protocol);
-#if INET6
+#if INET6_ENABLE
     FLAG_MERGE(server.service);
     FLAG_MERGE(server.netsec);
-#else /* INET6 */
+#else /* INET6_ENABLE */
     FLAG_MERGE(server.port);
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
     FLAG_MERGE(server.interval);
     FLAG_MERGE(server.preauthenticate);
     FLAG_MERGE(server.timeout);
@@ -856,6 +892,7 @@ static void optmerge(struct query *h2, struct query *h1, int force)
 
     FLAG_MERGE(server.plugin);
     FLAG_MERGE(server.plugout);
+
     FLAG_MERGE(wildcard);
     FLAG_MERGE(remotename);
     FLAG_MERGE(password);
@@ -879,6 +916,11 @@ static void optmerge(struct query *h2, struct query *h1, int force)
     FLAG_MERGE(warnings);
     FLAG_MERGE(fetchlimit);
     FLAG_MERGE(batchlimit);
+#ifdef	SSL_ENABLE
+    FLAG_MERGE(use_ssl);
+    FLAG_MERGE(sslkey);
+    FLAG_MERGE(sslcert);
+#endif
     FLAG_MERGE(expunge);
 
     FLAG_MERGE(properties);
@@ -890,6 +932,7 @@ static int load_params(int argc, char **argv, int optind)
     int	implicitmode, st;
     struct passwd *pw;
     struct query def_opts, *ctl;
+    struct stat rcstat;
 
     run.bouncemail = TRUE;
 
@@ -909,8 +952,20 @@ static int load_params(int argc, char **argv, int optind)
     def_opts.remotename = user;
     def_opts.listener = SMTP_MODE;
 
+    /* note the parse time, so we can pick up on modifications */
+    if (stat(rcfile, &rcstat) == -1)
+	report(stderr, _("couldn't time-check the run-control file\n"));
+    else
+	parsetime = rcstat.st_mtime;
+
     /* this builds the host list */
     if ((st = prc_parse_file(rcfile, !versioninfo)) != 0)
+	/*
+	 * FIXME: someday, send notification mail here if backgrounded.
+	 * Right now, that can happen if the user changes the rcfile
+	 * while the fetchmail is running in background.  Do similarly
+	 * for the other exit() calls in this function.
+	 */
 	exit(st);
 
     if ((implicitmode = (optind >= argc)))
@@ -1003,11 +1058,16 @@ static int load_params(int argc, char **argv, int optind)
 	    DEFAULT(ctl->mimedecode, FALSE);
 	    DEFAULT(ctl->server.dns, TRUE);
 	    DEFAULT(ctl->server.uidl, FALSE);
+#ifdef	SSL_ENABLE
+	    DEFAULT(ctl->use_ssl, FALSE);
+#endif
 	    DEFAULT(ctl->server.checkalias, FALSE);
 #undef DEFAULT
 
 	    /*
-	     * DNS support is required for some protocols.
+	     * DNS support is required for some protocols.  We used to
+	     * do this unconditionally, but it made fetchmail excessively
+	     * vulnerable to misconfigured DNS setups.
 	     *
 	     * If we're using ETRN, the smtp hunt list is the list of
 	     * systems we're polling on behalf of; these have to be 
@@ -1042,7 +1102,7 @@ static int load_params(int argc, char **argv, int optind)
 	    if (ctl->localnames && ctl->localnames->next && ctl->server.dns)
 	    {
 		ctl->server.dns = FALSE;
-		fprintf(stderr, _("fetchmail: warning: no DNS available to check multidrop fetches from %s\n"), ctl->server.pollname);
+		report(stderr, _("fetchmail: warning: no DNS available to check multidrop fetches from %s\n"), ctl->server.pollname);
 	    }
 #endif /* !HAVE_GETHOSTBYNAME || !HAVE_RES_SEARCH */
 
@@ -1139,7 +1199,7 @@ static int load_params(int argc, char **argv, int optind)
 	    if (ctl->server.timeout == -1)	
 		ctl->server.timeout = CLIENT_TIMEOUT;
 
-#if !INET6
+#if !INET6_ENABLE
 	    /* sanity checks */
 	    if (ctl->server.port < 0)
 	    {
@@ -1173,7 +1233,7 @@ static int load_params(int argc, char **argv, int optind)
 		    }
 		}
 	    }
-#endif /* !INET6 */
+#endif /* !INET6_ENABLE */
 
 	    /*
 	     * "I beg to you, have mercy on the week minds like myself."
@@ -1231,12 +1291,17 @@ static int load_params(int argc, char **argv, int optind)
     return(implicitmode);
 }
 
-static void termhook(int sig)
-/* to be executed on normal or signal-induced termination */
+static void terminate_poll(int sig)
+/* to be executed at the nd of a poll cycle */
 {
-    struct query	*ctl;
-
     /*
+     * Close all SMTP delivery sockets.  For optimum performance
+     * we'd like to hold them open til end of run, but (1) this
+     * loses if our poll interval is longer than the MTA's inactivity
+     * timeout, and (2) some MTAs (like smail) don't deliver after
+     * each message, but rather queue up mail and wait to actually
+     * deliver it until the input socket is closed. 
+     *
      * Sending SMTP QUIT on signal is theoretically nice, but led to a 
      * subtle bug.  If fetchmail was terminated by signal while it was 
      * shipping message text, it would hang forever waiting for a
@@ -1249,15 +1314,36 @@ static void termhook(int sig)
     if (sig != 0)
         report(stdout, _("terminated with signal %d\n"), sig);
     else
+    {
+	struct query *ctl;
+
 	/* terminate all SMTP connections cleanly */
 	for (ctl = querylist; ctl; ctl = ctl->next)
 	    if (ctl->smtp_socket != -1)
+	    {
 		SMTP_quit(ctl->smtp_socket);
+		close(ctl->smtp_socket);
+		ctl->smtp_socket = -1;
+	    }
+    }
 
 #ifdef POP3_ENABLE
+    /*
+     * Update UID information at end of each poll, rather than at end
+     * of run, because that way we don't lose all UIDL information since
+     * the beginning of time if fetchmail crashes.
+     */
     if (!check_only)
 	write_saved_lists(querylist, run.idfile);
 #endif /* POP3_ENABLE */
+}
+
+static void terminate_run(int sig)
+/* to be executed on normal or signal-induced termination */
+{
+    struct query	*ctl;
+
+    terminate_poll(sig);
 
     /* 
      * Craig Metz, the RFC1938 one-time-password guy, points out:
@@ -1446,26 +1532,26 @@ static void dump_params (struct runctl *runp,
 	}
 
 	if (ctl->server.protocol == P_POP3 
-#if INET6
+#if INET6_ENABLE
 	    && !strcmp(ctl->server.service, KPOP_PORT)
-#else /* INET6 */
+#else /* INET6_ENABLE */
 	    && ctl->server.port == KPOP_PORT
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
 	    && (ctl->server.preauthenticate == A_KERBEROS_V4 ||
 		ctl->server.preauthenticate == A_KERBEROS_V5))
 	    printf(_("  Protocol is KPOP with Kerberos %s authentication"),
 		   ctl->server.preauthenticate == A_KERBEROS_V5 ? "V" : "IV");
 	else
 	    printf(_("  Protocol is %s"), showproto(ctl->server.protocol));
-#if INET6
+#if INET6_ENABLE
 	if (ctl->server.service)
 	    printf(_(" (using service %s)"), ctl->server.service);
 	if (ctl->server.netsec)
 	    printf(_(" (using network security options %s)"), ctl->server.netsec);
-#else /* INET6 */
+#else /* INET6_ENABLE */
 	if (ctl->server.port)
 	    printf(_(" (using port %d)"), ctl->server.port);
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
 	else if (outlevel >= O_VERBOSE)
 	    printf(_(" (using default port)"));
 	if (ctl->server.uidl && (ctl->server.protocol != P_ETRN))
@@ -1476,6 +1562,10 @@ static void dump_params (struct runctl *runp,
 	    printf(_("  Kerberos V4 preauthentication enabled.\n"));
 	if (ctl->server.preauthenticate == A_KERBEROS_V5)
 	    printf(_("  Kerberos V5 preauthentication enabled.\n"));
+#ifdef	SSL_ENABLE
+	if (ctl->use_ssl)
+	    printf("  SSL encrypted sessions enabled.\n");
+#endif
 	if (ctl->server.timeout > 0)
 	    printf(_("  Server nonresponse timeout is %d seconds"), ctl->server.timeout);
 	if (ctl->server.timeout ==  CLIENT_TIMEOUT)
