@@ -18,13 +18,18 @@
 #define		P_IMAP_LOGIN	10
 #define		P_ETRN		11
 
-#if INET6
+#if INET6_ENABLE
 #define		SMTP_PORT	"smtp"
 #define		KPOP_PORT	"kpop"
-#else /* INET6 */
+#else /* INET6_ENABLE */
 #define		SMTP_PORT	25
 #define		KPOP_PORT	1109
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
+
+#ifdef SSL_ENABLE
+#define		SIMAP_PORT	993
+#define		SPOP3_PORT	995
+#endif
 
 /* preauthentication types */
 #define		A_PASSWORD	0	/* password or inline authentication */
@@ -139,11 +144,13 @@ struct query;
 struct method		/* describe methods for protocol state machine */
 {
     const char *name;		/* protocol name */
-#if INET6
+#if INET6_ENABLE
     const char *service;
-#else /* INET6 */
+    const char *sslservice;
+#else /* INET6_ENABLE */
     int	port;			/* service port */
-#endif /* INET6 */
+    int	sslport;		/* service port for ssl */
+#endif /* INET6_ENABLE */
     flag tagged;		/* if true, generate & expect command tags */
     flag delimited;		/* if true, accept "." message delimiter */
     int (*parse_response)(int, char *);
@@ -179,12 +186,12 @@ struct hostdata		/* shared among all user connections to given server */
     struct idlist *akalist;		/* server name first, then akas */
     struct idlist *localdomains;	/* list of pass-through domains */
     int protocol;			/* protocol type */
-#if INET6
+#if INET6_ENABLE
     char *service;			/* IPv6 service name */
     void *netsec;			/* IPv6 security request */
-#else /* INET6 */
+#else /* INET6_ENABLE */
     int port;				/* TCP/IP service port number */
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
     int interval;			/* # cycles to skip between polls */
     int preauthenticate;		/* preauthentication mode to try */
     int timeout;			/* inactivity timout in seconds */
@@ -257,6 +264,9 @@ struct query
     int	fetchlimit;		/* max # msgs to get in single poll */
     int	batchlimit;		/* max # msgs to pass in single SMTP session */
     int	expunge;		/* max # msgs to pass between expunges */
+    flag use_ssl;		/* use SSL encrypted session */
+    char *sslkey;		/* optional SSL private key file */
+    char *sslcert;		/* optional SSL certificate file */
     char *properties;		/* passthrough properties for extensions */
 
     /* internal use -- per-poll state */
@@ -384,6 +394,14 @@ int gen_transact ();
 #define FORWARDING_WAIT	4	/* waiting for listener response */
 extern int phase;
 
+/* response hooks can use this to identify the query stage */
+#define STAGE_GETAUTH	0
+#define STAGE_GETRANGE	1
+#define STAGE_GETSIZES	2
+#define STAGE_FETCH	3
+#define STAGE_LOGOUT	4
+extern int stage;
+
 /* mark values for name lists */
 #define XMIT_ACCEPT	1	/* accepted; matches local domain or name */
 #define XMIT_REJECT	2	/* rejected; no match */
@@ -423,7 +441,7 @@ char *str_find(struct idlist **, int);
 char *idpair_find(struct idlist **, const char *);
 void append_str_list(struct idlist **, struct idlist **);
 void expunge_uids(struct query *);
-void update_str_lists(struct query *);
+void uid_end_query(struct query *);
 void write_saved_lists(struct query *, const char *);
 
 /* rcfile_y.y */
