@@ -49,9 +49,9 @@
 
 #include "md5.h"
 
-#if OPIE
+#if OPIE_ENABLE
 #include <opie.h>
-#endif /* OPIE */
+#endif /* OPIE_ENABLE */
 
 #ifndef strstr		/* glibc-2.1 declares this as a macro */
 extern char *strstr();	/* needed on sysV68 R3V7.1. */
@@ -107,6 +107,8 @@ int imap_ok(int sock, char *argbuf)
 	}
 	if (strstr(buf, "FLAGS"))
 	    seen = (strstr(buf, "SEEN") != (char *)NULL);
+	if (strstr(buf, "PREAUTH"))
+	    preauth = TRUE;
     } while
 	(tag[0] != '\0' && strncmp(buf, tag, strlen(tag)));
 
@@ -142,13 +144,18 @@ int imap_ok(int sock, char *argbuf)
 	else if (strncmp(cp, "BAD", 3) == 0)
 	    return(PS_ERROR);
 	else if (strncmp(cp, "NO", 2) == 0)
-	    return(PS_ERROR);
+	{
+	    if (stage == STAGE_GETAUTH) 
+		return(PS_AUTHFAIL);	/* RFC2060, 6.2.2 */
+	    else
+		return(PS_ERROR);
+	}
 	else
 	    return(PS_PROTOCOL);
     }
 }
 
-#if OPIE
+#if OPIE_ENABLE
 static int do_otp(int sock, struct query *ctl)
 {
     int i, rval;
@@ -194,7 +201,7 @@ static int do_otp(int sock, struct query *ctl)
     };
 
     if (rval)
-	return PS_AUTHFAIL;
+	return(PS_AUTHFAIL);
 
     to64frombits(buffer, response, strlen(response));
 
@@ -211,7 +218,7 @@ static int do_otp(int sock, struct query *ctl)
     else
 	return PS_AUTHFAIL;
 };
-#endif /* OPIE */
+#endif /* OPIE_ENABLE */
 
 #ifdef KERBEROS_V4
 #if SIZEOF_INT == 4
@@ -593,7 +600,7 @@ static int do_gssauth(int sock, char *hostname, char *username)
     }
     to64frombits(buf1, send_token.value, send_token.length);
     if (outlevel >= O_DEBUG) {
-        report(stdout, _("Requesting authorisation as %s\n"), username);
+        report(stdout, _("Requesting authorization as %s\n"), username);
         report(stdout, "IMAP> %s\n",buf1);
     }
     strcat(buf1, "\r\n");
@@ -749,7 +756,6 @@ static int do_cram_md5 (int sock, struct query *ctl)
 {
     int result;
     int len;
-    int quot;
     unsigned char buf1[1024];
     unsigned char msg_id[768];
     unsigned char response[16];
@@ -787,28 +793,19 @@ static int do_cram_md5 (int sock, struct query *ctl)
      * computed by applying the keyed MD5 algorithm from [KEYED-MD5] where
      * the key is a shared secret and the digested text is the timestamp
      * (including angle-brackets).
-     *
-     * If the usename has a space in it, it's surrounded by string quotes 
-     * before being shipped.  This is not in conformance with the CRAM-MD5
-     * RFCs (which don't describe any kind of quoting and imply that the
-     * username must be a single token), but at least one server accepts
-     * it anyway (the greeting line says "InterChange IMAP4 Server v3.51.06").
-     * If this doesn't work, sending the unquoted name wouldn't have worked
-     * either, so we lost nothing.
      */
 
     hmac_md5 (ctl->password, strlen (ctl->password),
               msg_id, strlen (msg_id),
               response, sizeof (response));
 
-    quot = (int) strpbrk (ctl->remotename, " ");
 #ifdef HAVE_SNPRINTF
     snprintf (reply, sizeof (reply),
 #else
     sprintf(reply,
 #endif
-              "%s%s%s %02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x", 
-              quot ? "\"" : "", ctl->remotename, quot ? "\"" : "",
+              "%s %02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x", 
+              ctl->remotename,
               response[0], response[1], response[2], response[3],
               response[4], response[5], response[6], response[7],
               response[8], response[9], response[10], response[11],
@@ -900,7 +897,7 @@ int imap_getauth(int sock, struct query *ctl, char *greeting)
     if (preauth)
 	return(PS_SUCCESS);
 
-#if OPIE
+#if OPIE_ENABLE
     if ((ctl->server.protocol == P_IMAP) && strstr(capabilities, "AUTH=X-OTP"))
     {
 	if (outlevel >= O_DEBUG)
@@ -908,7 +905,7 @@ int imap_getauth(int sock, struct query *ctl, char *greeting)
 	if (do_otp(sock, ctl) == PS_SUCCESS)
 	    return(PS_SUCCESS);
     };
-#endif /* OPIE */
+#endif /* OPIE_ENABLE */
 
 #ifdef GSSAPI
     if (strstr(capabilities, "AUTH=GSSAPI"))
@@ -982,13 +979,7 @@ int imap_getauth(int sock, struct query *ctl, char *greeting)
     {
         if (outlevel >= O_DEBUG)
             report (stdout, _("NTLM authentication is supported\n"));
-    if ((ok = do_imap_ntlm (sock, ctl)))
-        {
-            if (outlevel >= O_MONITOR)
-                report (stdout, "IMAP> *\n");
-            SockWrite (sock, "*\r\n", 3);
-        }
-        return ok;
+        return do_imap_ntlm (sock, ctl);
     }
 #endif /* NTLM_ENABLE */
 
@@ -1155,7 +1146,7 @@ static int imap_fetch_headers(int sock, struct query *ctl,int number,int *lenp)
     number -= expunged;
 
     /*
-     * This is blessed by RFC 1176, RFC1730, RFC2060.
+     * This is blessed by RFC1176, RFC1730, RFC2060.
      * According to the RFCs, it should *not* set the \Seen flag.
      */
     gen_send(sock, "FETCH %d RFC822.HEADER", number);
@@ -1192,7 +1183,8 @@ static int imap_fetch_body(int sock, struct query *ctl, int number, int *lenp)
      *
      * However...*don't* do this if we're using keep to suppress deletion!
      * In that case, marking the seen flag is the only way to prevent the
-     * message from being re-fetched on subsequent runs.
+     * message from being re-fetched on subsequent runs (and according
+     * to RFC2060 p.43 this fetch should set Seen as a side effect).
      */
     switch (imap_version)
     {
@@ -1257,6 +1249,26 @@ static int imap_trail(int sock, struct query *ctl, int number)
 	/* UW IMAP returns "OK FETCH", Cyrus returns "OK Completed" */
 	if (strstr(buf, "OK"))
 	    break;
+
+#ifdef __UNUSED__
+	/*
+	 * Any IMAP server that fails to set Seen on a BODY[TEXT]
+	 * fetch violates RFC2060 p.43 (top).  This becomes an issue
+	 * when keep is on, because seen messages aren't deleted and
+	 * get refetched on each poll.  As a workaround, if keep is on
+	 * we can set the Seen flag explicitly.
+	 *
+	 * This code isn't used yet because we don't know of any IMAP
+	 * servers broken in this way.
+	 */
+	if (ctl->keep)
+	    if ((ok = gen_transact(sock,
+			imap_version == IMAP4 
+				? "STORE %d +FLAGS.SILENT (\\Seen)"
+				: "STORE %d +FLAGS (\\Seen)", 
+			number)))
+		return(ok);
+#endif /* __UNUSED__ */
     }
 
     return(PS_SUCCESS);
@@ -1314,11 +1326,13 @@ static int imap_logout(int sock, struct query *ctl)
 const static struct method imap =
 {
     "IMAP",		/* Internet Message Access Protocol */
-#if INET6
+#if INET6_ENABLE
     "imap",
-#else /* INET6 */
+    "imaps",
+#else /* INET6_ENABLE */
     143,                /* standard IMAP2bis/IMAP4 port */
-#endif /* INET6 */
+    993,                /* ssl IMAP2bis/IMAP4 port */
+#endif /* INET6_ENABLE */
     TRUE,		/* this is a tagged protocol */
     FALSE,		/* no message delimiter */
     imap_ok,		/* parse command response */
