@@ -71,6 +71,12 @@
 #define LA_CONFIGDUMP	47
 #define LA_YYDEBUG	48
 
+#ifdef SSL_ENABLE
+#define LA_SSL		49
+#define LA_SSLKEY	50
+#define LA_SSLCERT	51
+#endif
+
 /* options still left: CDgGhHjJoORwWxXYz */
 static const char *shortoptions = 
 	"?Vcsvd:NqL:f:i:p:UP:A:t:E:Q:u:akKFnl:r:S:Z:b:B:e:m:T:I:M:yw:";
@@ -126,14 +132,20 @@ static const struct option longoptions[] = {
   {"bsmtp",	required_argument, (int *) 0, LA_BSMTP       },
   {"lmtp",	no_argument,       (int *) 0, LA_LMTP        },
 
-#ifdef INET6
+#ifdef INET6_ENABLE
   {"netsec",	required_argument, (int *) 0, LA_NETSEC      },
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
 
-#if (defined(linux) && !INET6) || defined(__FreeBSD__)
+#ifdef SSL_ENABLE
+  {"ssl",       no_argument,       (int *) 0, LA_SSL        },
+  {"sslkey",    required_argument, (int *) 0, LA_SSLKEY     },
+  {"sslcert",   required_argument, (int *) 0, LA_SSLCERT    },
+#endif
+
+#if (defined(linux) && !INET6_ENABLE) || defined(__FreeBSD__)
   {"interface",	required_argument, (int *) 0, LA_INTERFACE   },
   {"monitor",	required_argument, (int *) 0, LA_MONITOR     },
-#endif /* (defined(linux) && !INET6) || defined(__FreeBSD__) */
+#endif /* (defined(linux) && !INET6_ENABLE) || defined(__FreeBSD__) */
   {"plugin",	required_argument, (int *) 0, LA_PLUGIN      },
   {"plugout",	required_argument, (int *) 0, LA_PLUGOUT     },
 
@@ -287,17 +299,14 @@ struct query *ctl;	/* option record to be initialized */
 	    break;
 	case 'f':
 	case LA_RCFILE:
-	    rcfile = (char *) xmalloc(strlen(optarg)+1);
-	    strcpy(rcfile,optarg);
+	    rcfile = (char *) xstrdup(optarg);
 	    break;
 	case 'i':
 	case LA_IDFILE:
-	    rctl->idfile = (char *) xmalloc(strlen(optarg)+1);
-	    strcpy(rctl->idfile,optarg);
+	    rctl->idfile = (char *) xstrdup(optarg);
 	    break;
 	case LA_POSTMASTER:
-	    rctl->postmaster = (char *) xmalloc(strlen(optarg)+1);
-	    strcpy(rctl->postmaster,optarg);
+	    rctl->postmaster = (char *) xstrdup(optarg);
 	    break;
 	case LA_NOBOUNCE:
 	    run.bouncemail = FALSE;
@@ -325,11 +334,11 @@ struct query *ctl;	/* option record to be initialized */
 	    else if (strcasecmp(optarg,"kpop") == 0)
 	    {
 		ctl->server.protocol = P_POP3;
-#if INET6
+#if INET6_ENABLE
 		ctl->server.service = KPOP_PORT;
-#else /* INET6 */
+#else /* INET6_ENABLE */
 		ctl->server.port = KPOP_PORT;
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
 #ifdef KERBEROS_V5
 		ctl->server.preauthenticate =  A_KERBEROS_V5;
 #else
@@ -363,11 +372,11 @@ struct query *ctl;	/* option record to be initialized */
 	    break;
 	case 'P':
 	case LA_PORT:
-#if INET6
+#if INET6_ENABLE
 	    ctl->server.service = optarg;
-#else /* INET6 */
+#else /* INET6_ENABLE */
 	    ctl->server.port = xatoi(optarg, &errflag);
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
 	    break;
 	case LA_PREAUTH:
 	    if (strcmp(optarg, "password") == 0)
@@ -464,7 +473,7 @@ struct query *ctl;	/* option record to be initialized */
 	    do {
 		struct idlist	*idp = save_str(&ctl->antispam, NULL, 0);;
 
-		idp->val.status.num = atoi(cp);
+		idp->val.status.num = xatoi(cp, &errflag);
 	    } while
 		((cp = strtok((char *)NULL, ",")));
 	    break;
@@ -506,7 +515,7 @@ struct query *ctl;	/* option record to be initialized */
 #endif /* NET_SECURITY */
 	    break;
 
-#if (defined(linux) && !INET6) || defined(__FreeBSD__)
+#if (defined(linux) && !INET6_ENABLE) || defined(__FreeBSD__)
 	case 'I':
 	case LA_INTERFACE:
 	    interface_parse(optarg, &ctl->server);
@@ -515,7 +524,7 @@ struct query *ctl;	/* option record to be initialized */
 	case LA_MONITOR:
 	    ctl->server.monitor = xstrdup(optarg);
 	    break;
-#endif /* (defined(linux) && !INET6) || defined(__FreeBSD__) */
+#endif /* (defined(linux) && !INET6_ENABLE) || defined(__FreeBSD__) */
 	case LA_PLUGIN:
 	    ctl->server.plugin = xstrdup(optarg);
 	    break;
@@ -523,6 +532,20 @@ struct query *ctl;	/* option record to be initialized */
 	    ctl->server.plugout = xstrdup(optarg);
 	    break;
 
+#ifdef SSL_ENABLE
+	case LA_SSL:
+	    ctl->use_ssl = FLAG_TRUE;
+	    break;
+
+	case LA_SSLKEY:
+	    ctl->sslkey = xstrdup(optarg);
+	    break;
+
+	case LA_SSLCERT:
+	    ctl->sslcert = xstrdup(optarg);
+	    break;
+#endif
+
 	case 'y':
 	case LA_YYDEBUG:
 	    yydebug = TRUE;
@@ -574,9 +597,14 @@ struct query *ctl;	/* option record to be initialized */
 	P(_("  -i, --idfile      specify alternate UIDs file\n"));
 	P(_("      --postmaster  specify recipient of last resort\n"));
 	P(_("      --nobounce    redirect bounces from user to postmaster.\n"));
-#if (defined(linux) && !INET6) || defined(__FreeBSD__)
+#if (defined(linux) && !INET6_ENABLE) || defined(__FreeBSD__)
 	P(_("  -I, --interface   interface required specification\n"));
 	P(_("  -M, --monitor     monitor interface for activity\n"));
+#endif
+#if defined( SSL_ENABLE )
+	P(_("      --ssl         enable ssl encrypted session\n"));
+	P(_("      --sslkey      ssl private key file\n"));
+	P(_("      --sslcert     ssl client certificate\n"));
 #endif
 	P(_("      --plugin      specify external command to open connection\n"));
 	P(_("      --plugout     specify external command to open smtp connection\n"));
