@@ -21,29 +21,23 @@
 #include  "socket.h"
 #include  "i18n.h"
 
-#if OPIE
+#if OPIE_ENABLE
 #include <opie.h>
-#endif /* OPIE */
+#endif /* OPIE_ENABLE */
 
 #ifndef strstr		/* glibc-2.1 declares this as a macro */
 extern char *strstr();	/* needed on sysV68 R3V7.1. */
 #endif /* strstr */
 
-static int pop3_phase;
-#define PHASE_GETAUTH	0
-#define PHASE_GETRANGE	1
-#define PHASE_GETSIZES	2
-#define PHASE_FETCH	3
-#define PHASE_LOGOUT	4
 static int last;
 #ifdef SDPS_ENABLE
 char *sdps_envfrom;
 char *sdps_envto;
 #endif /* SDPS_ENABLE */
 
-#if OPIE
+#if OPIE_ENABLE
 static char lastok[POPBUFSIZE+1];
-#endif /* OPIE */
+#endif /* OPIE_ENABLE */
 
 int pop3_ok (int sock, char *argbuf)
 /* parse command response */
@@ -68,14 +62,14 @@ int pop3_ok (int sock, char *argbuf)
 
 	if (strcmp(buf,"+OK") == 0)
 	{
-#if OPIE
+#if OPIE_ENABLE
 	    strcpy(lastok, bufp);
-#endif /* OPIE */
+#endif /* OPIE_ENABLE */
 	    ok = 0;
 	}
 	else if (strncmp(buf,"-ERR", 4) == 0)
 	{
-	    if (pop3_phase > PHASE_GETAUTH) 
+	    if (stage > STAGE_GETAUTH) 
 		ok = PS_PROTOCOL;
 	    /*
 	     * We're checking for "lock busy", "unable to lock", 
@@ -122,11 +116,9 @@ int pop3_getauth(int sock, struct query *ctl, char *greeting)
     int ok;
     char *start,*end;
     char *msg;
-#if OPIE
+#if OPIE_ENABLE
     char *challenge;
-#endif /* OPIE */
-
-    pop3_phase = PHASE_GETAUTH;
+#endif /* OPIE_ENABLE */
 
 #ifdef SDPS_ENABLE
     /*
@@ -168,7 +160,7 @@ int pop3_getauth(int sock, struct query *ctl, char *greeting)
 #endif /* RPA_ENABLE */
 	    ok = gen_transact(sock, "USER %s", ctl->remotename);
 
-#if OPIE
+#if OPIE_ENABLE
 	/* see RFC1938: A One-Time Password System */
 	if (challenge = strstr(lastok, "otp-")) {
 	  char response[OPIE_RESPONSE_MAX+1];
@@ -191,7 +183,7 @@ int pop3_getauth(int sock, struct query *ctl, char *greeting)
 	  ok = gen_transact(sock, "PASS %s", response);
 	  break;
 	}
-#endif /* OPIE */
+#endif /* OPIE_ENABLE */
 
 	/* ordinary validation, no one-time password or RPA */ 
 	ok = gen_transact(sock, "PASS %s", ctl->password);
@@ -385,8 +377,6 @@ static int pop3_getrange(int sock,
     int ok;
     char buf [POPBUFSIZE+1];
 
-    pop3_phase = PHASE_GETRANGE;
-
     /* Ensure that the new list is properly empty */
     ctl->newsaved = (struct idlist *)NULL;
 
@@ -478,8 +468,6 @@ static int pop3_getsizes(int sock, int count, int *sizes)
 {
     int	ok;
 
-    /* pop3_phase = PHASE_GETSIZES */
-
     if ((ok = gen_transact(sock, "LIST")) != 0)
 	return(ok);
     else
@@ -523,8 +511,6 @@ static int pop_fetch_headers(int sock, struct query *ctl,int number,int *lenp)
     int ok;
     char buf[POPBUFSIZE+1];
 
-    /* pop3_phase = PHASE_FETCH */
-
     gen_send(sock, "TOP %d 0", number);
     if ((ok = pop3_ok(sock, buf)) != 0)
 	return(ok);
@@ -541,8 +527,6 @@ static int pop3_fetch(int sock, struct query *ctl, int number, int *lenp)
     int ok;
     char buf[POPBUFSIZE+1];
 
-    /* pop3_phase = PHASE_FETCH */
-
 #ifdef SDPS_ENABLE
     /*
      * See http://www.demon.net/services/mail/sdps-tech.html
@@ -631,8 +615,6 @@ static int pop3_logout(int sock, struct query *ctl)
 {
     int ok;
 
-    /* pop3_phase = PHASE_LOGOUT */
-
     ok = gen_transact(sock, "QUIT");
     if (!ok)
 	expunge_uids(ctl);
@@ -643,11 +625,13 @@ static int pop3_logout(int sock, struct query *ctl)
 const static struct method pop3 =
 {
     "POP3",		/* Post Office Protocol v3 */
-#if INET6
+#if INET6_ENABLE
     "pop3",		/* standard POP3 port */
-#else /* INET6 */
+    "pop3s",		/* ssl POP3 port */
+#else /* INET6_ENABLE */
     110,		/* standard POP3 port */
-#endif /* INET6 */
+    995,		/* ssl POP3 port */
+#endif /* INET6_ENABLE */
     FALSE,		/* this is not a tagged protocol */
     TRUE,		/* this uses a message delimiter */
     pop3_ok,		/* parse command response */
