@@ -95,11 +95,11 @@ static int smtp_open(struct query *ctl)
 	for (idp = ctl->smtphunt; idp; idp = idp->next)
 	{
 	    char	*cp, *parsed_host;
-#ifdef INET6 
+#ifdef INET6_ENABLE 
 	    char	*portnum = SMTP_PORT;
 #else
 	    int		portnum = SMTP_PORT;
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
 
 	    xalloca(parsed_host, char *, strlen(idp->id) + 1);
 
@@ -109,11 +109,11 @@ static int smtp_open(struct query *ctl)
 	    if ((cp = strrchr(parsed_host, '/')))
 	    {
 		*cp++ = 0;
-#ifdef INET6 
+#ifdef INET6_ENABLE 
 		portnum = cp;
 #else
 		portnum = atoi(cp);
-#endif /* INET6 */
+#endif /* INET6_ENABLE */
 	    }
 
 	    if ((ctl->smtp_socket = SockOpen(parsed_host,portnum,NULL,
@@ -395,12 +395,12 @@ static int handle_smtp_report(struct query *ctl, struct msgblk *msg)
 	 * coming from this address, probably due to an
 	 * anti-spam domain exclusion.  Respect this.  Don't
 	 * try to ship the message, and don't prevent it from
-	 * being deleted.  Typical values:
+	 * being deleted.  Default values:
 	 *
-	 * 501 = exim's old antispam response
-	 * 550 = exim's new antispam response (temporary)
-	 * 553 = sendmail 8.8.7's generic REJECT 
 	 * 571 = sendmail's "unsolicited email refused"
+	 * 550 = exim's new antispam response (temporary)
+	 * 501 = exim's old antispam response
+	 * 554 = Postfix antispam response.
 	 *
 	 */
 	SMTP_rset(ctl->smtp_socket);    /* stay on the safe site */
@@ -454,7 +454,10 @@ static int handle_smtp_report(struct query *ctl, struct msgblk *msg)
     case 553: /* invalid sending domain */
 	/*
 	 * These latter days 553 usually means a spammer is trying to
-	 * cover his tracks.
+	 * cover his tracks.  We never bouncemail on these, because 
+	 * (a) the return address is invalid by definition, and 
+	 * (b) we wouldn't want spammers to get confirmation that
+	 * this address is live, anyway.
 	 */
 	SMTP_rset(ctl->smtp_socket);    /* stay on the safe side */
 	send_bouncemail(ctl, msg, XMIT_ACCEPT,
@@ -497,7 +500,8 @@ int open_sink(struct query *ctl, struct msgblk *msg,
 	else if (ctl->mimemsg & MSG_IS_7BIT)
 	    fputs(" BODY=7BIT", sinkfp);
 
-	fprintf(sinkfp, " SIZE=%d\r\n", msg->reallen);
+	/* exim's BSMTP processor does not handle SIZE */
+	/* fprintf(sinkfp, " SIZE=%d\r\n", msg->reallen); */
 
 	/*
 	 * RFC 1123 requires that the domain name part of the
@@ -863,7 +867,7 @@ int close_sink(struct query *ctl, struct msgblk *msg, flag forward)
     else if (ctl->bsmtp)
     {
 	/* implicit disk-full check here... */
-	fputs("..\r\n", sinkfp);
+	fputs(".\r\n", sinkfp);
 	if (strcmp(ctl->bsmtp, "-"))
 	    fclose(sinkfp);
 	if (ferror(sinkfp))
