@@ -6,6 +6,8 @@
 
 #include "config.h"
 
+#include <sys/stat.h>
+#include <errno.h>
 #include <stdio.h>
 #include <limits.h>
 #if defined(STDC_HEADERS)
@@ -70,6 +72,7 @@ static struct idlist *scratchlist;
 void initialize_saved_lists(struct query *hostlist, const char *idfile)
 /* read file of saved IDs and attach to each host */
 {
+    struct stat statbuf;
     FILE	*tmpfp;
     struct query *ctl;
 
@@ -77,6 +80,24 @@ void initialize_saved_lists(struct query *hostlist, const char *idfile)
     for (ctl = hostlist; ctl; ctl = ctl->next)
 	ctl->skipped = ctl->oldsaved = ctl->newsaved = (struct idlist *)NULL;
 
+    errno = 0;
+
+    /*
+     * Croak if the uidl directory does not exist.
+     * This probably means an NFS mount failed and we can't
+     * see a uidl file that ought to be there.
+     * Question: is this a portable check? It's not clear
+     * that all implementations of lstat() will return ENOTDIR
+     * rather than plain ENOENT in this case...
+     */
+   if (lstat(idfile, &statbuf) < 0) {
+     if (errno == ENOTDIR) 
+    {
+      report(stderr, "lstat: %s: %s\n", idfile, strerror(errno));
+      exit(PS_IOERR);
+    }
+   }
+
     /* let's get stored message UIDs from previous queries */
     if ((tmpfp = fopen(idfile, "r")) != (FILE *)NULL)
     {
@@ -92,58 +113,63 @@ void initialize_saved_lists(struct query *hostlist, const char *idfile)
 
 	while (fgets(buf, POPBUFSIZE, tmpfp) != (char *)NULL)
 	{
-	  /*
-	   * At this point, we assume the bug has two fields -- a user@host 
-	   * part, and an ID part. Either field may contain spurious @ signs. 
-           * The previous version of this code presumed one could split at 
-           * the rightmost '@'.  This is not correct, as InterMail puts an 
-           * '@' in the UIDL.
-	   */
+	    /*
+	     * At this point, we assume the bug has two fields -- a user@host 
+	     * part, and an ID part. Either field may contain spurious @ signs.
+	     * The previous version of this code presumed one could split at 
+	     * the rightmost '@'.  This is not correct, as InterMail puts an 
+	     * '@' in the UIDL.
+	     */
 	  
-	  /* very first, skip leading spaces */
-	  user = buf + strspn(buf, " \t");
+	    /* first, skip leading spaces */
+	    user = buf + strspn(buf, " \t");
 
-	  /* First, we split the buf into a userhost part and an id part */
-	  if ( (delimp1 = strpbrk(user, " \t")) != NULL ) {
-		id = delimp1 + strspn(delimp1, " \t");	/* set pointer to id */
+	    /* First, we split the buf into a userhost part and an id part */
+	    if ((id = strchr(user, '<')) != NULL ) 	/* set pointer to id */
+	    {
+	        for (delimp1 = id; delimp1 >= user; delimp1--)
+		    if ((*delimp1 != ' ') && (*delimp1 != '\t'))
+			break;
+		delimp1++; /* but what if there is only white space ?!? */
 	  	saveddelim1 = *delimp1;	/* save char after token */
 		*delimp1 = '\0';		/* delimit token with \0 */
-		if (id != NULL) {
-			/* now remove trainling white space chars from id */
-	  		if ( (delimp2 = strpbrk(id, " \t\n")) != NULL ) {
-				saveddelim2 = *delimp2;
-				*delimp2 = '\0';
-			}
-	      		atsign = strrchr(user, '@');
-	      		if (atsign) {
-				*atsign = '\0';
-				host = atsign + 1;
+		if (id != NULL) 
+		{
+		    /* now remove trailing white space chars from id */
+		    if ((delimp2 = strpbrk(id, " \t\n")) != NULL ) {
+			saveddelim2 = *delimp2;
+			*delimp2 = '\0';
+		    }
+		    atsign = strrchr(user, '@');
+		    if (atsign) {
+			*atsign = '\0';
+			host = atsign + 1;
 
-			}
-			for (ctl = hostlist; ctl; ctl = ctl->next) {
-				if (ctl->server.truename &&
-			 	    strcasecmp(host, ctl->server.truename) == 0
-			 	    && strcasecmp(user, ctl->remotename) == 0) {
+		    }
+		    for (ctl = hostlist; ctl; ctl = ctl->next) {
+			if (ctl->server.truename &&
+			    strcasecmp(host, ctl->server.truename) == 0
+			    && strcasecmp(user, ctl->remotename) == 0) {
 	
-					save_str(&ctl->oldsaved, id, UID_SEEN);
-					break;
-				}
+			    save_str(&ctl->oldsaved, id, UID_SEEN);
+			    break;
 			}
-			/* if it's not in a host we're querying,
-			** save it anyway */
-			if (ctl == (struct query *)NULL) {
+		    }
+		    /* if it's not in a host we're querying,
+		    ** save it anyway */
+		    if (ctl == (struct query *)NULL) {
 				/* restore string */
-				*delimp1 = saveddelim1;
-				*atsign = '@';
-	  			if (delimp2 != NULL) {
-					*delimp2 = saveddelim2;
-				}
-				save_str(&scratchlist, buf, UID_SEEN);
+			*delimp1 = saveddelim1;
+			*atsign = '@';
+			if (delimp2 != NULL) {
+			    *delimp2 = saveddelim2;
 			}
+			save_str(&scratchlist, buf, UID_SEEN);
+		    }
 		}
 	    }
 	}
-	fclose(tmpfp);
+	fclose(tmpfp);	/* not checking should be safe, mode was "r" */
     }
 
     if (outlevel >= O_DEBUG)
@@ -368,14 +394,16 @@ void expunge_uids(struct query *ctl)
 	    idl->val.status.mark = UID_EXPUNGED;
 }
 
-void update_str_lists(struct query *ctl)
-/* perform end-of-query actions on UID lists */
+void uid_end_query(struct query *ctl) 
+/* finish a query */
 {
+    /* old state of mailbox is now irrelevant */
     free_str_list(&ctl->oldsaved);
     free_str_list(&scratchlist);
     ctl->oldsaved = ctl->newsaved;
     ctl->newsaved = (struct idlist *) NULL;
 
+    /* debugging code */
     if (ctl->server.uidl && outlevel >= O_DEBUG)
     {
 	struct idlist *idp;
